@@ -190,7 +190,8 @@ typedef enum ObjectClass
 	OCLASS_TYPE_MAP,			/* pg_type_map */
 	OCLASS_PROC_MAP,			/* pg_proc_map */
 	OCLASS_TRANSFORM,			/* pg_transform */
-	OCLASS_TABLEGROUP
+	OCLASS_TABLEGROUP,
+	OCLASS_ATTR_EXT,			/* pg_attr_ext */
 } ObjectClass;
 
 #define LAST_OCLASS		OCLASS_TABLEGROUP
