@@ -421,4 +421,10 @@ DECLARE_UNIQUE_INDEX(pg_database_name_map_dest_dbname_index, 3431, on pg_databas
 DECLARE_UNIQUE_INDEX(pg_mysql_srs_basics_index, 7005, on pg_mysql_srs_basics using btree(srid oid_ops));
 #define MySQLSRSBasicsIndexId 7005
 
+DECLARE_UNIQUE_INDEX(pg_matview_mvrelid_index, 7008, on pg_matview using btree(mv_relid oid_ops));
+#define MatViewMvrelidIndexId 7008
+
+DECLARE_UNIQUE_INDEX(pg_attr_ext_relid_attnum_index, 12357, on pg_attr_ext using btree(attrelid oid_ops, attnum int2_ops));
+#define AttrExtRelidAttnumIndexId 12357
+
 #endif							/* INDEXING_H */
