@@ -116,6 +116,9 @@ CATALOG(pg_attribute,1249,AttributeRelationId) BKI_BOOTSTRAP BKI_WITHOUT_OIDS BK
 	 *			 has one, see pg_class.reltoastrelid)
 	 *		'm': Value can be stored compressed inline
 	 *		'x': Value can be stored compressed inline or in "secondary"
+	 *		'c': Value should be compressed in storage node, as specified in CREATE TABLE stmt for the column by users.
+	 *			 newly added in Klustron-1.4.
+	 *			 the field may not necessarily be stored compressed, per additional conditions in build_column_data_type()
 	 * Note that 'm' fields can also be moved out to secondary storage,
 	 * but only as a last resort ('e' and 'x' fields are moved first).
 	 *----------
