@@ -30,12 +30,7 @@ CATALOG(pg_sequence,2224,SequenceRelationId) BKI_WITHOUT_OIDS
 	int64		seqmin;
 	int64		seqcache;
 	bool		seqcycle;
-	/*
-	  dzw: fetch&store reserved sequence values from storage shard.
-	  Below fields are invalid for temp sequences.
-	  last fetched value from remote storage shard and persisted there.
-	*/
-	int64		last_fetched;
+	char		seqcache_method;
 } FormData_pg_sequence;
 
 /* ----------------
@@ -45,4 +40,7 @@ CATALOG(pg_sequence,2224,SequenceRelationId) BKI_WITHOUT_OIDS
  */
 typedef FormData_pg_sequence *Form_pg_sequence;
 
+#define SEQCACHE_METHOD_STATIC 's'
+#define SEQCACHE_METHOD_DYNAMIC 'd'
+
 #endif							/* PG_SEQUENCE_H */
