@@ -12,7 +12,10 @@
 CATALOG(pg_tablegroup,12620,TableGroupRelationId) BKI_ROWTYPE_OID(12621,TableGroupRelation_Rowtype_Id) BKI_SCHEMA_MACRO
 {
 	NameData	tgname;			/* table group name */
-	Oid 				tgowner;		/* table group owner */
+	Oid 			tgowner;		/* table group owner */
+	Oid				tgparent;
+	int32			tgpartcount;
+
 #ifdef CATALOG_VARLEN			/* variable-length fields start here */
 	text		reloptions[1];	/* access-method-specific options */
 #endif
