@@ -30,4 +30,6 @@ extern DestReceiver *CreateIntoRelDestReceiver(IntoClause *intoClause);
 
 extern ObjectAddress create_ctas_nodata(List *tlist, IntoClause *into);
 
+extern void delete_matview_entry(Oid mvid);
+extern void insert_matview_extra(Oid mvrelid, Oid storelid, bool varying, List*reqcols);
 #endif							/* CREATEAS_H */
