@@ -31,5 +31,13 @@ extern char *get_database_name(Oid dbid);
 extern int get_database_name2(Oid dbid, StringInfo str);
 extern int get_database_name3(Oid dbid, NameData *nm);
 extern void check_encoding_locale_matches(int encoding, const char *collate, const char *ctype);
+extern  Oid init_mydboid_startup(const char *in_dbname);
+extern  int get_db_enc_collate(NameData *name);
+extern  void ExecDbNameMappingStmt(DbNameMappingStmt *stmt);
+extern  const char* map_nspname_from_dbnames(const char*datname, const char*stordb_name, NameData *res);
+extern  bool map_shard_db_name2(StringInfo qname, const char*datname, const char*nspname);
+extern  const char* map_shard_db_name(const char*datname, const char*nspname, NameData *res);
+extern  void drop_schema_name_mapping(const char*schema);
+extern  void create_schema_name_mapping(const char*schema);
 
 #endif							/* DBCOMMANDS_H */
