@@ -10,6 +10,7 @@ typedef struct TableGroupOpts
 {
 	int32		vl_len_;		/* varlena header (do not touch directly!) */
 	Oid 		shard;
+	int32		hash;
 	bool		frozen;
 } TableGroupOpts;
 
@@ -28,4 +29,7 @@ extern void AlterTableGroupOwner_oid(Oid tgid, Oid newowner);
 /* Help function to adjust tablegroup's option when restore data into a new cluster */
 extern size_t ModifyAllTableGroupShardid(Oid from, Oid to);
 
+extern int GetTableGroupPartitions(const char *name);
+extern char* GetSubTableGroupForHash(const char *name, int32 hash);
+extern void DumpTableGroupPartitions(const char *name, StringInfo str);
 #endif
