@@ -4,9 +4,22 @@
 #include "postgres.h"
 
 #include "access/parallel.h"
+#include "commands/explain.h"
 #include "nodes/execnodes.h"
 #include "nodes/plannodes.h"
 
+/*
+ * Read pg_class directly to get the latest sharid information, because
+ * the syscache has not been updated at this time.
+ */
+extern Oid GetRelationShardByPassCache(Oid relid);
+
+/* Check if the given relation use cantian storage engine */
+extern bool use_cantian_engine(Relation rel);
+
+/* Choose a node when access cantian storage */
+extern Oid choose_cantian_node(Oid shardid);
+
 /**
  * @brief Initialize the plan state of remote plan
  */
@@ -60,6 +73,8 @@ extern void ExecStoreRemoteTuple(TypeInputInfo *inputinfo,
 				 MYSQL_ROW row,
 				 unsigned long *lengths,
 				 enum enum_field_types *fieldtypes,
-				 TupleTableSlot *slot,
-				 int firstNCols);
+				 TupleTableSlot *slot);
+
+bool explain_remote_plan(RemotePlanState *planstate, ExplainState *es);
+
 #endif
\ No newline at end of file
