@@ -346,7 +346,6 @@ typedef enum NodeTag
 	T_LoadStmt,
 	T_CreateDomainStmt,
 	T_CreatedbStmt,
-	T_DbNameMappingStmt,
 	T_DropdbStmt,
 	T_VacuumStmt,
 	T_ExplainStmt,
@@ -431,7 +430,6 @@ typedef enum NodeTag
 	T_ShowSchemasStmt,
 	T_ShowTablesStmt,
 	T_ShowTableStatusStmt,
-	T_ShowColumnsStmt,
 	T_ShowCreateDBStmt,
 	T_ShowCreateSchemaStmt,
 	T_ShowCreateTableStmt,
