@@ -881,7 +881,12 @@ typedef struct RemtePlan
 	Plan plan;
 	/* The target shard */
 	Oid shard;
-	
+	/*
+	  which channel to use to do remote scan.
+	  -1 to scan using any ASI
+	*/
+	int branch_id;
+
 	Relids relids;
 	/* List of parent rt index of relids*/
 	List *parent_relids;
