@@ -96,6 +96,19 @@ typedef struct TableFunc
 	int			location;		/* token location, or -1 if unknown */
 } TableFunc;
 
+struct PartitionSpec;
+
+// aux type used in vary matview
+typedef struct TblCols
+{
+	Oid relid;  // the OID of the queried relation of the matview's query
+	Oid idxrelid; // chosen/specified index relation ID of the queried relation
+	Oid storage_idxid; // created index on storage relation of the matview corresponding to the index idxrelid of relation relid
+	int nattrs; // NO. of attrs of the PK/Unique index, also NO. of slots of required_cols and query_cols
+	int2vector *required_cols; // indexed columns of specified unique/PK index, all of them must appear in query of the matview
+	int2vector *query_cols; // fould columns from query of matview
+} TblCols;
+
 /*
  * IntoClause - target information for SELECT INTO, CREATE TABLE AS, and
  * CREATE MATERIALIZED VIEW
@@ -110,12 +123,18 @@ typedef struct IntoClause
 
 	RangeVar   *rel;			/* target relation name */
 	List	   *colNames;		/* column names to assign, or NIL */
+	struct PartitionSpec       *partspec; /* how to partition the table */
 	List	   *options;		/* options from WITH clause */
 	int			options_location;
 	OnCommitAction onCommit;	/* what do we do at COMMIT? */
 	char	   *tableSpaceName; /* table space to use, or NULL */
 	Node	   *viewQuery;		/* materialized view's SELECT query */
 	bool		skipData;		/* true for WITH NO DATA */
+	/* below fields are not set by parser but used to pass info around functions. Used for VARYING matviews and partitioned tables/matvies. */
+	bool		is_varying_matview; // true if creating a varying matview.
+	Oid			storage_relid;	// Only set for VARYING matviews with partitioned tables.
+	List*		storage_parts_relids;//list of partitions relation OIDs
+	List		*required_tblcols;
 } IntoClause;
 
 
@@ -674,9 +693,9 @@ typedef struct SubLink
  * The values are assigned to the global PARAM_EXEC params indexed by parParam
  * (the parParam and args lists must have the same ordering).  setParam is a
  * list of the PARAM_EXEC params that are computed by the sub-select, if it
- * is an initplan; they are listed in order by sub-select output column
- * position.  (parParam and setParam are integer Lists, not Bitmapsets,
- * because their ordering is significant.)
+ * is an initplan or MULTIEXPR plan; they are listed in order by sub-select
+ * output column position.  (parParam and setParam are integer Lists, not
+ * Bitmapsets, because their ordering is significant.)
  *
  * Also, the planner computes startup and per-call costs for use of the
  * SubPlan.  Note that these include the cost of the subquery proper,
@@ -709,13 +728,15 @@ typedef struct SubPlan
 	/* Note: parallel_safe does not consider contents of testexpr or args */
 	/* Information for passing params into and out of the subselect: */
 	/* setParam and parParam are lists of integers (param IDs) */
-	List	   *setParam;		/* initplan subqueries have to set these
-								 * Params for parent plan */
+	List	   *setParam;		/* initplan and MULTIEXPR subqueries have to
+								 * set these Params for parent plan */
 	List	   *parParam;		/* indices of input Params from parent plan */
 	List	   *args;			/* exprs to pass as parParam values */
 	/* Estimated execution costs: */
 	Cost		startup_cost;	/* one-time setup cost */
 	Cost		per_call_cost;	/* cost for each subplan evaluation */
+	/* Copied from original SubLink, but placed at end for ABI stability */
+	int			subLinkId;		/* ID (1..n); 0 if not MULTIEXPR */
 } SubPlan;
 
 /*
