@@ -37,6 +37,11 @@ typedef struct VarAlias
 	int levelno;
 } VarAlias;
 
+typedef struct OutputFuncArgs
+{
+	bool array_for_storage;
+} OutputFuncArgs;
+
 typedef struct RemotePrintExprContext
 {
 	EState *estate;
@@ -87,6 +92,19 @@ typedef struct RemotePrintExprContext
 
 	/* Do not print expr to mysql sql, just verify */
 	bool noprint;
+	// printing a function call array argument which should be printed as multiple arguments
+	bool unwrap_func_array_arg;
+	/*
+	  printing a function call as select target? currently we need to do
+	  special treatment when doing so, for example we want to request mysql to
+	  return binary json format in its json function calls.
+	*/
+	bool printing_func_call_target;
+	// the function OID that we are serializing, set when serializing a funccall or opr.
+	Oid serializing_funcid;
+
+	OutputFuncArgs output_func_args;
+
 } RemotePrintExprContext;
 
 extern void InitRemotePrintExprContext(RemotePrintExprContext *rpec, List*rtable);
@@ -109,6 +127,7 @@ extern bool is_expr_printable(const Expr *expr, RemotePrintExprContext *rpec);
 extern int snprint_expr(StringInfo buf, const Expr *expr, RemotePrintExprContext *rpec);
 extern int snprint_collation_id(StringInfo str, Oid collid, RemotePrintExprContext *rpec);
 extern int snprint_collation(StringInfo str, const Expr *expr, RemotePrintExprContext *rpec);
-extern Oid my_output_funcoid(Oid typid, bool *typIsVarlena);
+
+extern Oid my_output_funcoid(Oid typid, bool *typisvarlena, struct OutputFuncArgs *args);
 extern bool can_bind_param_expr(EState *estate, List *params);
 #endif							/* PRINT_H */
