@@ -15,24 +15,29 @@
 #ifndef REMOTE_PATH_H
 #define REMOTE_PATH_H
 
+#include "postgres.h"
+
 #define IS_REMOTE_RELOPT(root, rel) \
 	((rel)->relshardid && rt_fetch((rel)->relid, (root)->parse->rtable)->relkind == RELKIND_RELATION)
 
 #define IS_REMOTESEQ_RELOPT(root, rel) \
 	((rel)->relshardid && rt_fetch((rel)->relid, (root)->parse->rtable)->relkind == RELKIND_SEQUENCE)
 
+#define IS_REMOTEMATVIEW_RELOPT(root, rel) \
+	((rel)->relshardid && rt_fetch((rel)->relid, (root)->parse->rtable)->relkind == RELKIND_MATVIEW)
+
 extern Path *create_remotescan_path(PlannerInfo *root, RelOptInfo *rel,
-				    Relids required_outer, bool parallel_safe);
+				    Relids required_outer, bool parallel_safe, bool use_cursor);
 extern RemotePath *
 create_remote_index_path(PlannerInfo *root, RelOptInfo *rel, IndexOptInfo *index,
 		List *clauses, List *indexclausecols,
 		List *indexorderbys, List *indexorderbycols,
 		List *pathkeys, ScanDirection indexscandir,
 		bool indexonly, Relids required_outer,
-		double loop_count, bool partial_safe);
+		double loop_count, bool partial_plan, bool cursor);
 
 extern bool can_do_remote_join(PlannerInfo *root, RelOptInfo *rel1, RelOptInfo *rel2,
-			       JoinType jt, List *restrictionList);
+							   RelOptInfo *joinrel, SpecialJoinInfo *sjinfo, List *restrictionList);
 extern int add_remote_path_to_joinrel(PlannerInfo *root,
 				       RelOptInfo *joinrel,
 				       RelOptInfo *outerrel,
