@@ -31,7 +31,6 @@ PG_KEYWORD("absolute", ABSOLUTE_P, UNRESERVED_KEYWORD)
 PG_KEYWORD("access", ACCESS, UNRESERVED_KEYWORD)
 PG_KEYWORD("action", ACTION, UNRESERVED_KEYWORD)
 PG_KEYWORD("add", ADD_P, UNRESERVED_KEYWORD)
-PG_KEYWORD("adddate", ADDDATE, COL_NAME_KEYWORD)
 PG_KEYWORD("admin", ADMIN, UNRESERVED_KEYWORD)
 PG_KEYWORD("after", AFTER, UNRESERVED_KEYWORD)
 PG_KEYWORD("aggregate", AGGREGATE, UNRESERVED_KEYWORD)
@@ -78,7 +77,6 @@ PG_KEYWORD("chain", CHAIN, UNRESERVED_KEYWORD)
 PG_KEYWORD("char", CHAR_P, COL_NAME_KEYWORD)
 PG_KEYWORD("character", CHARACTER, COL_NAME_KEYWORD)
 PG_KEYWORD("characteristics", CHARACTERISTICS, UNRESERVED_KEYWORD)
-PG_KEYWORD("charset", CHARSET, TYPE_FUNC_NAME_KEYWORD)
 PG_KEYWORD("check", CHECK, RESERVED_KEYWORD)
 PG_KEYWORD("checkpoint", CHECKPOINT, UNRESERVED_KEYWORD)
 PG_KEYWORD("class", CLASS, UNRESERVED_KEYWORD)
@@ -123,8 +121,6 @@ PG_KEYWORD("cycle", CYCLE, UNRESERVED_KEYWORD)
 PG_KEYWORD("data", DATA_P, UNRESERVED_KEYWORD)
 PG_KEYWORD("database", DATABASE, UNRESERVED_KEYWORD)
 PG_KEYWORD("databases", DATABASES, UNRESERVED_KEYWORD)
-PG_KEYWORD("date_add", DATE_ADD, COL_NAME_KEYWORD)
-PG_KEYWORD("date_sub", DATE_SUB, COL_NAME_KEYWORD)
 PG_KEYWORD("datetime", DATETIME, COL_NAME_KEYWORD)
 PG_KEYWORD("day", DAY_P, UNRESERVED_KEYWORD)
 PG_KEYWORD("deallocate", DEALLOCATE, UNRESERVED_KEYWORD)
@@ -334,6 +330,7 @@ PG_KEYWORD("parallel", PARALLEL, UNRESERVED_KEYWORD)
 PG_KEYWORD("parser", PARSER, UNRESERVED_KEYWORD)
 PG_KEYWORD("partial", PARTIAL, UNRESERVED_KEYWORD)
 PG_KEYWORD("partition", PARTITION, UNRESERVED_KEYWORD)
+PG_KEYWORD("partitions", PARTITIONS, UNRESERVED_KEYWORD)
 PG_KEYWORD("passing", PASSING, UNRESERVED_KEYWORD)
 PG_KEYWORD("password", PASSWORD, UNRESERVED_KEYWORD)
 PG_KEYWORD("persist", PERSIST, TYPE_FUNC_NAME_KEYWORD)
@@ -434,7 +431,6 @@ PG_KEYWORD("storage", STORAGE, UNRESERVED_KEYWORD)
 PG_KEYWORD("stored", STORED, UNRESERVED_KEYWORD)
 PG_KEYWORD("strict", STRICT_P, UNRESERVED_KEYWORD)
 PG_KEYWORD("strip", STRIP_P, UNRESERVED_KEYWORD)
-PG_KEYWORD("subdate", SUBDATE, COL_NAME_KEYWORD)
 PG_KEYWORD("subscription", SUBSCRIPTION, UNRESERVED_KEYWORD)
 PG_KEYWORD("substring", SUBSTRING, COL_NAME_KEYWORD)
 PG_KEYWORD("symmetric", SYMMETRIC, RESERVED_KEYWORD)
@@ -453,8 +449,6 @@ PG_KEYWORD("then", THEN, RESERVED_KEYWORD)
 PG_KEYWORD("ties", TIES, UNRESERVED_KEYWORD)
 PG_KEYWORD("time", TIME, COL_NAME_KEYWORD)
 PG_KEYWORD("timestamp", TIMESTAMP, COL_NAME_KEYWORD)
-PG_KEYWORD("timestampadd", TIMESTAMPADD, COL_NAME_KEYWORD)
-PG_KEYWORD("timestampdiff", TIMESTAMPDIFF, COL_NAME_KEYWORD)
 PG_KEYWORD("tinyblob", TINYBLOB, COL_NAME_KEYWORD)
 PG_KEYWORD("tinyint", TINYINT, COL_NAME_KEYWORD)
 PG_KEYWORD("tinytext", TINYTEXT, COL_NAME_KEYWORD)
