@@ -38,5 +38,10 @@ extern List *raw_parser(const char *str);
 extern List *SystemFuncName(char *name);
 extern TypeName *SystemTypeName(char *name);
 
+typedef enum enum_extra_syntax_mode {
+	EXTRA_SYNTAX_MODE_MYSQL = 'm',
+	EXTRA_SYNTAX_MODE_TDENGINE = 't'
+} enum_extra_syntax_mode;
+extern int extra_syntax_mode;
 
 #endif							/* PARSER_H */
