@@ -81,4 +81,9 @@ extern bool IsLocalVirtualPid(int32 vpid);
  */
 #define MAX_BACKENDS	0x3FFFF
 
+struct Port;
+typedef int (*BackendStartup_hook_type) (struct Port *port);
+
+extern PGDLLIMPORT BackendStartup_hook_type BackendStartup_hook;
+
 #endif							/* _POSTMASTER_H */
