@@ -39,6 +39,9 @@ extern Oid comp_node_id;
 #define CHECK_HA_ROLE 0x20
 
 #define MAX_HOSTADDR_LEN 128 // align with def in metadata tables.
+
+#define METASHARD_DOMAIN_ID 1
+
 /*
  * A mysql connection for synchronous communication, currently only used to
  * communicate with mysql metadata cluster. We don't cache connection
@@ -105,6 +108,46 @@ static inline bool is_rcr_primary(int role)
 extern const char *cluster_rcr_role_str(int rcr_role);
 extern int cluster_rcr_role;
 
+typedef enum enum_storage_node_type {
+	STORAGE_NODE_TYPE_INVALID,
+	STORAGE_NODE_TYPE_KUNLUN_MYSQL,
+	STORAGE_NODE_TYPE_KUNLUN_MARIADB,
+	STORAGE_NODE_TYPE_KUNLUN_MYSQL_CANTIAN,
+	STORAGE_NODE_TYPE_KUNLUN_MARIADB_CANTIAN
+} enum_storage_node_type;
+
+typedef enum enum_gvno_reuse_mode {
+	GVNO_REUSE_OFF,
+	GVNO_REUSE_FOR_COMMITS,
+	GVNO_REUSE_FOR_READS,
+	GVNO_REUSE_FOR_BOTH
+} enum_gvno_reuse_mode;
+extern int gvno_reuse_mode;
+
+struct AsyncStmtInfo;
+extern enum_storage_node_type get_storage_node_type(struct AsyncStmtInfo*asi);
+extern enum_storage_node_type init_storage_node_type(void);
+
+extern enum_storage_node_type g_storage_node_type;
+inline static bool storage_node_is_mysql()
+{
+	init_storage_node_type();
+	return g_storage_node_type == STORAGE_NODE_TYPE_KUNLUN_MYSQL ||
+		g_storage_node_type == STORAGE_NODE_TYPE_KUNLUN_MYSQL_CANTIAN;
+}
+inline static bool storage_node_is_mariadb()
+{
+	init_storage_node_type();
+	return g_storage_node_type == STORAGE_NODE_TYPE_KUNLUN_MARIADB ||
+		g_storage_node_type == STORAGE_NODE_TYPE_KUNLUN_MARIADB_CANTIAN;
+}
+inline static bool storage_node_is_cantian()
+{
+	init_storage_node_type();
+	return g_storage_node_type == STORAGE_NODE_TYPE_KUNLUN_MYSQL_CANTIAN ||
+		g_storage_node_type == STORAGE_NODE_TYPE_KUNLUN_MARIADB_CANTIAN;
+}
+
 /**
  * @brief Connect to the meta cluster master, and return the internal connection singleton.
  * 
