@@ -5,7 +5,7 @@
  *	  table sharding connection functionality.
  *
  *
- * Copyright (c) 2019-2024 ZettaDB inc. All rights reserved.
+ * Copyright (c) 2019-2021 ZettaDB inc. All rights reserved.
  *
  * This source code is licensed under Apache 2.0 License,
  * combined with Common Clause Condition 1.0, as detailed in the NOTICE file.
@@ -36,52 +36,27 @@ extern bool enable_remote_cursor;
 extern int remote_cursor_prefetch_rows;
 struct MYSQL;
 /**
- * flag bits for AsyncStmtInfo::conn_flags
  * CONN_VALID	: Connection is valid. if not, need to reconnect at next use of the connection.
  * CON_RESET	: Connection is reset. if so, need to resend SET NAMES and cached.
  * 				  mysql session vars before sending any stmt through it
- * CONN_MASTER  : connected to a master
- * CONN_MVCC	: global MVCC effective on the connection
- * CONN_INUSE	: the asi is used by current stmt. cleared at end of every stmt
  */
 #define CONN_VALID 0x1
 #define CONN_RESET 0x2
 #define CONN_MASTER 0x4
 #define CONN_MVCC 0x8
-#define CONN_INUSE 0x10
-
-/*
-  nodeid value space is 0x00ffffff, still big enough
-  to every shard node for every client session, 256 connections can be started
-  at most, this should be sufficient for parallel query execution.
-*/
-static inline bool IsSnapshotNode(Oid nodeid)
-{
-	return (nodeid & 0xff000000) != 0;
-}
-
 
 typedef struct ShardConnection
 {
 	Oid shard_id;	   // Connections to one shard's all nodes.
 	uint8_t num_nodes; // number of payload slots in the 3 arrays below.
-	/*
-	  We may start multiple channels to the same shard node for parallel query execution,
-	  apart from the head of the ShardConnection list, the rest are all parallel snapshot channels(PSC),
-	  and the nodeid of each PSC is uniquely derived from the original one with num_parallel_conns[i]
-	  OR'ed to highest byte of nodeids[i], so existing logic still works and we can also
-	  always figure out a snapshot channel belongs to which shard node, and reuse connections to a target shard node.
-	  These channels can be reused in later queries of later txns.
-
-	  The head of list never contain PSCs, following ShardConnection elements all contain PSCs.
-	*/
-	struct ShardConnection *next_parallel_conns;
 	/*
 	 * Whenever a connection to storage node is made once, the nodeids[i],
 	 * conns[i] and conn_flags[i] always belong to the same storage node.
 	 * */
 	Oid nodeids[MAX_NODES_PER_SHARD];  // shard node ids. insert in order
 	MYSQL *conns[MAX_NODES_PER_SHARD]; // conn[i] is nodeids[i]'s connection.
+
+	char conn_flags[MAX_NODES_PER_SHARD];
 	MYSQL conn_objs[MAX_NODES_PER_SHARD]; // append only
 } ShardConnection;
 
@@ -92,9 +67,8 @@ typedef struct ShardConnection
  * */
 typedef struct AsyncStmtInfo
 {
-	Oid shard_id;
-	Oid node_id; // when this is a snapshot channel, GetRawNodeId(node_id) == donor_node_id
-	Oid donor_node_id; /* the original(raw) node id from which this channel took its snapshot from. */
+	Oid shard_id, node_id;
+	Oid donor_shard_id, donor_node_id; /* the real shard/node id */
 	int status; // mysql async API wait&cont status.
 	uint64 client_query_id;
 
@@ -106,7 +80,6 @@ typedef struct AsyncStmtInfo
 
 	/* The mysql client conn */
 	MYSQL *conn;
-	//ShardConnection *shard_conn;// the one containing conn
 
 	/*
 	 * Inserted/Deleted/Modified rows of INSERT/DELETE/UPDATE stmts executed in
@@ -128,11 +101,6 @@ typedef struct AsyncStmtInfo
 	 */
 	uint32_t nwarnings;
 
-	/*
-	  OR'ed CONN_XXX flag bits above.
-	*/
-	char conn_flags;
-
 	/*
 	 * Whether write(INSERT/UPDATE/DELETE) and read(SELECT) commands were
 	 * executed in current pg stmt. Transaction mgr should accumulate the
@@ -154,6 +122,7 @@ typedef struct AsyncStmtInfo
 
 	/* True if current conn is not the leader of parallel vnodes */
 	bool snapshot_channel;
+
 	/* 
 	 * The thread id of the leader connection which generate the snapshot used by
 	 * parallel worker process.
@@ -171,30 +140,11 @@ typedef struct AsyncStmtInfo
 	/* The handle still in use */
 	List *stmt_inuse;
 
-	struct AsyncStmtInfo *next_asi;// to the same shard node
-
-	/* ----- sql logger states -------- */
+	/* ----- sql logger -------- */
 	struct timeval 	sqllog_starttime;
-	StringInfoData sqllog_buf;
+	char sqllog_buf[256];
 } AsyncStmtInfo;
 
-typedef struct ASIListIterator
-{
-	AsyncStmtInfo *cur_asi;
-	int ref_idx;
-	int n_elems;
-	int elem_idx;
-} ASIListIterator;
-
-/*
-  init itr and move it to 1st ASI, and return its ptr.
-*/
-AsyncStmtInfo * begin_asi_iter(ASIListIterator *itr);
-/*
-  move itr to next ASI, and return its ptr. if no more ASI, return NULL, and itr is invalid.
-*/
-AsyncStmtInfo *asi_iter_next(ASIListIterator *itr);
-
 inline static bool ASIAccessed(AsyncStmtInfo *asi)
 {
 	return asi->did_write || asi->did_ddl || asi->did_read;
@@ -220,12 +170,10 @@ extern void InitShardingSession(void);
 extern void ResetCommunicationHub(void);
 extern void ResetCommunicationHubStmt(bool ended_clean);
 
-extern AsyncStmtInfo *GetAsyncStmtInfo(Oid shardid);
-extern AsyncStmtInfo *GetAsyncStmtInfoNode(Oid shardid, Oid shardNodeId, bool req_chk_onfail, bool want_master, bool want_psc);
+extern AsyncStmtInfo *GetAsyncStmtInfoByIndex(int i);
 extern int GetAsyncStmtInfoUsed(void);
-
-extern bool GetParallelSnapshotNodeConn(Oid shardid, Oid nodeid, bool prefer_snapshot_node);
-extern AsyncStmtInfo* AllocSnapshotChannel(Oid shardid, Oid nodeid);
+extern AsyncStmtInfo *GetAsyncStmtInfo(Oid shardid);
+extern AsyncStmtInfo *GetAsyncStmtInfoNode(Oid shardid, Oid shardNodeId, bool req_chk_onfail, bool want_master);
 
 /*
  * In RC mode, reset the global visible version at the start of the command.
@@ -257,14 +205,16 @@ extern void send_stmt_to_all_inuse_sync(char *stmt, size_t len, CmdType cmdtype,
 /**
  * @brief Send statement to all of the shards in current cluster, and wait for the completion of the statement
  */
-extern void send_stmt_to_all_conns_sync(char *stmt, size_t len, CmdType cmdtype, bool owns_it,
-				  enum enum_sql_command sqlcom);
+extern void send_stmt_to_all_shards_sync(char *stmt, size_t len, CmdType cmdtype, bool owns_it,
+					 enum enum_sql_command sqlcom);
 
 /**
  * @brief Wait for all of the statements in queue to be completed
  */
 extern void flush_all_stmts(void);
 
+extern AsyncStmtInfo *FindAnyShard(void);
+
 /**
  * @brief Cancel all of the statements in queue, and wait for the completion of the running statements
  * 
