@@ -28,12 +28,12 @@ extern void deserialize_stmt_result(StmtHandle *handle, Datum *output, bool *nul
 /**
  * @brief Cache newly created statement into cache, and mark it inuse
  */
-extern void cache_prepared_stmt(Oid nodeid, const char *query, int len, struct st_mysql_stmt *stmt);
+extern void cache_prepared_stmt(Oid nodeid, const char *query, int len, bool cursor, struct st_mysql_stmt *stmt);
 
 /**
  * @brief FInd idle prepared statement with the digest query and on shard nodeid
  */
-extern struct st_mysql_stmt *find_prepared_stmt(Oid nodeid, const char *query, int len);
+extern struct st_mysql_stmt *find_prepared_stmt(Oid nodeid, const char *query, int len, bool cursor);
 
 /**
  * @brief Mark the given statement inuse=false, then other routine can reuse it by call find_prepared_stmt(..)
