@@ -47,7 +47,7 @@ typedef enum
 
 extern PGDLLIMPORT int log_statement;
 
-typedef List* (*ParseQuery_hook_type) (const char **query_string);
+typedef List* (*ParseQuery_hook_type) (const char **query_string, Bitmapset **internal_stmts);
 
 extern PGDLLIMPORT ParseQuery_hook_type ParseQuery_hook;
 
