@@ -29,4 +29,7 @@ extern int bin_search_with_context(const void *key, const void *base,
 	size_t num_elems,
 	size_t elesz, func_cmp_ctx_t cmpf, int *inspos, void *ctx);
 
+extern uint64_t MurmurHash64A ( const void * key, int len, unsigned int seed );
+extern unsigned int MurmurHash2 ( const void * key, int len, unsigned int seed );
+extern unsigned int MurmurHashNeutral2 ( const void * key, int len, unsigned int seed );
 #endif
