@@ -281,6 +281,8 @@ typedef struct StdRdOptions
 	int autoextend_size;
 	int tablegroup;
 	int column_family;
+	int table_path;
+	int tablespace;
 } StdRdOptions;
 
 #define HEAP_MIN_FILLFACTOR			10
