@@ -39,6 +39,7 @@ enum SysCacheIdentifier
 	AMPROCNUM,
 	ATTNAME,
 	ATTNUM,
+	ATTEXTRELIDNUM,
 	AUTHMEMMEMROLE,
 	AUTHMEMROLEMEM,
 	AUTHNAME,
@@ -70,6 +71,7 @@ enum SysCacheIdentifier
 	INDEXRELID,
 	LANGNAME,
 	LANGOID,
+	MATVIEW,
 	MYSQLSRSBASICS,
 	NAMESPACENAME,
 	NAMESPACEOID,
