@@ -123,6 +123,7 @@ if __name__ == '__main__':
     parser.add_argument('--ha_mode', type=str, default='mgr', choices=['mgr','no_rep', 'rbr'])
     parser.add_argument('--valgrind', help="whether to use valgrind", default=False, action='store_true')
     parser.add_argument('--nopreload', help="whether to avoid setting LD_PRELOAD ", default=False, action='store_true')
+    parser.add_argument('--cantian', help="whether for cantian installation", default=False, action='store_true')
 
     args = parser.parse_args()
 
@@ -134,7 +135,7 @@ if __name__ == '__main__':
     config_template_file = install_path + "/resources/postgresql.conf"
 
     mysql_conn_params = {}
-    mysql_conn_params = common.mysql_shard_check(meta_jscfg, args.ha_mode)
+    mysql_conn_params = common.mysql_shard_check(meta_jscfg, args.ha_mode, args.cantian)
     mysql_conn_params['database'] = 'Kunlun_Metadata_DB'
             
     add_comp_self(install_path, config_template_file, mysql_conn_params, "self.json", args)
