@@ -133,14 +133,6 @@ def add_shards_to_cluster(mysql_conn_params, cluster_name, config_path, install_
     meta_cursor.close()
     meta_cursor0.close()
 
-    # create the default database in each new shard.
-    for master in masters:
-        master_conn = mysql.connector.connect(**master)
-        master_cursor = master_conn.cursor()
-        master_cursor.execute("create database postgres_$$_public")
-        master_cursor.close()
-        master_conn.close()
-
     add_new_shards_to_all_computing_nodes(cluster_id, meta_conn, jscfg)
     meta_conn.close()
     jsconf.close()
