@@ -14,6 +14,7 @@ parser = argparse.ArgumentParser(description='create meta tables and initialize
 parser.add_argument('--config', type=str, help="meta-data shard config file path")
 parser.add_argument('--bootstrap_sql', type=str, help="path of sql file to create meta-data tables")
 parser.add_argument('--ha_mode', type=str, default='rbr', choices=['mgr','no_rep', 'rbr'])
+parser.add_argument('--cantian', help="whether for cantian installation", default=False, action='store_true')
 
 args = parser.parse_args()
 mysql_conn_params = {
@@ -34,7 +35,7 @@ mysql_conn_params = {
 jsconf = open(args.config)
 jstr = jsconf.read()
 jscfg = json.loads(jstr)
-mysql_conn_params = common.mysql_shard_check(jscfg, args.ha_mode)
+mysql_conn_params = common.mysql_shard_check(jscfg, args.ha_mode, args.cantian)
 
 mysql_conn_params['database'] = 'mysql'
 fbootstrap_sql = open(args.bootstrap_sql)
