@@ -62,10 +62,14 @@ def mysql_node_check_rbr(conn_params):
     conn = connect_mysql(conn_params)
     mysql_version_check(conn, conn_params)
     csr=conn.cursor()
-    csr.execute("select HOST, PORT from performance_schema.replication_connection_configuration where channel_name='kunlun_repl'")
-    row = csr.fetchone()
+    try:
+        csr.execute("show slave status for channel 'kunlun_repl'")
+        row = csr.fetchone()
+    except mysql.connector.errors.DatabaseError as err:
+        row = None
+
     csr.close()
-    if row == None or row[0] == None or row[0] == '' or row[1] == None:
+    if row == None or row[1] == None or row[1] == '' or row[3] == None:
         csr=conn.cursor()
         csr.execute("show slave hosts")
         rows=csr.fetchall()
@@ -79,11 +83,11 @@ def mysql_node_check_rbr(conn_params):
     else:
         csr.close()
         conn.close()
-        return row[0], row[1]
+        return row[1], row[3]
 
 # make sure all nodes are in the same shard and has the same master node
 # return the master node params suitable for mysql connection
-def mysql_shard_check(shard_conn_params, ha_mode):
+def mysql_shard_check(shard_conn_params, ha_mode, cantian=False):
     cur_prim_ip = ''
     cur_prim_port = 0
     prim_node = None
@@ -93,14 +97,17 @@ def mysql_shard_check(shard_conn_params, ha_mode):
         node['use_pure'] = True
         if 'ssl_disabled' in mysql.connector.constants.DEFAULT_CONFIGURATION:
             node['ssl_disabled'] = True
+        if cantian or ha_mode == 'no_rep':
+            prim_node = node
+            break;
         if ha_mode == 'mgr':
             node_mip, node_mport = mysql_node_check_mgr(node)
         elif ha_mode == 'rbr':
             node_mip, node_mport = mysql_node_check_rbr(node)
-        else:
-            node_mip, node_mport = mysql_node_check_norep(node)
         mastermap[(node['ip'], node['port'])] = (node_mip, node_mport)
     for node in shard_conn_params:
+        if cantian or ha_mode == 'no_rep':
+            break
         mkey = (node['ip'], node['port'])
         while True:
             if mkey not in mastermap:
