@@ -11,7 +11,6 @@ import json
 import add_comp_nodes
 import add_shards
 import common
-import time
 from distutils.util import strtobool
 from common import my_print
 
@@ -39,7 +38,7 @@ meta_cursor = meta_conn.cursor(prepared=True)
 meta_cursor0 = meta_conn.cursor()
 
 # insert cluster info into db_clusters
-stmt = "insert into db_clusters(name, nick_name, owner, ddl_log_tblname, business, memo, ha_mode, status, when_created) values(%s, %s, %s, %s, %s, %s, %s, %s, %s)"
+stmt = "insert into db_clusters(name, nick_name, owner, ddl_log_tblname, business, memo, ha_mode) values(%s, %s, %s, %s, %s, %s, %s)"
 seq_stmt = "select create_sequence('%s', '%s', 1, 1, 16384*65536*65536*65536 - 1, 1, 0, 1000, 1)" % ('kunlun_metadata_db', args.cluster_name)
 ddl_log_tblname='ddl_ops_log_'+args.cluster_name  # must be like this, don't change the format
 
@@ -47,9 +46,7 @@ my_print("Creating database cluster " + args.cluster_name)
 my_print("Step 1. Inserting meta-data row for database cluster " + args.cluster_name)
 meta_cursor0.execute("start transaction")
 
-timestr = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(time.time()))
-meta_cursor.execute(stmt, (args.cluster_name, args.cluster_biz, args.cluster_owner,
-    ddl_log_tblname, args.cluster_biz, args.cluster_biz, args.ha_mode, 'inuse', timestr))
+meta_cursor.execute(stmt, (args.cluster_name, args.cluster_biz, args.cluster_owner, ddl_log_tblname, args.cluster_biz, args.cluster_biz, args.ha_mode))
 meta_cursor.execute(seq_stmt)
 unused = meta_cursor.fetchall()
 
