@@ -200,7 +200,7 @@ CREATE TABLE `ddl_ops_log_template_table` (
   `user_name` varchar(64) NOT NULL,
   `role_name` varchar(64) NOT NULL,
   `search_path` text NOT NULL,
-  `optype` enum('create','drop','rename','alter','replace', 'remap_shardid', 'add_shard', 'add_node', 'delete_shard', 'delete_node', 'add_computer', 'rcr_shard','others') NOT NULL,
+  `optype` enum('create','drop','rename','alter','replace', 'remap_shardid', 'add_shard', 'add_node', 'delete_shard', 'delete_node', 'add_computer', 'rcr_shard', 'others') NOT NULL,
   `objtype` enum('db','index','matview','partition','schema','seq','table','func','role_or_group','proc','stats','user','view', 'others') NOT NULL,
   `when_logged` timestamp(6) NULL DEFAULT current_timestamp(6),
   `sql_src` longtext NOT NULL,
@@ -448,11 +448,9 @@ BEGIN
     set @initiator_id = initiator_id;
     set @txn_id = txn_id;
 
-    set @ddl_holder = COALESCE(IS_USED_LOCK('DDL'), 0);
-
-    if @ddl_holder != CONNECTION_ID() then
+    if COALESCE(IS_USED_LOCK('DDL'), 0) != CONNECTION_ID() then
       SIGNAL SQLSTATE '45000'
-        SET MESSAGE_TEXT = 'DDL lock is NOT held by current session.';
+        SET MESSAGE_TEXT = 'DDL lock is hold by current session';
     end if;
 
     SET @sql = CONCAT(
@@ -486,13 +484,13 @@ END ;
 create table backup_storage(
 	id int unsigned primary key auto_increment,
 	name varchar(256),
-	stype enum('HDFS', 'S3', 'EBS','CEPH','SSH','OTHER'), -- type of storage service
+	stype enum('HDFS', 'S3', 'ALIOSS','EBS','CEPH','SSH','OTHER'), -- type of storage service
 	-- connection info
 	conn_str varchar(8192),
 	hostaddr varchar(8192),
 	port int,
 	user_name varchar(128),
-	passwd varchar(32),
+	passwd varchar(1024),
 	extra text
 ) ENGINE=InnoDB DEFAULT charset=utf8;
  
@@ -786,9 +784,9 @@ create table `cluster_rcr_infos` (
 	`conf_delay_sync` int NOT NULL DEFAULT '0',
 	`sync_host_delay` int NOT NULL DEFAULT '0',
 	`slave_replica_delay` int NOT NULL DEFAULT '0',
-	`double_sync` int NOT NULL DEFAULT '0',
-	`master_replica_delay` int NOT NULL DEFAULT '0',
-	`smap_version` int NOT NULL DEFAULT '1',
+        `double_sync` int NOT NULL DEFAULT '0',
+        `master_replica_delay` int NOT NULL DEFAULT '0',
+        `smap_version` int NOT NULL DEFAULT '1',
 	`when_created` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
 	primary key(`id`)
 );
