@@ -11,6 +11,7 @@ if __name__ == "__main__":
     parser = argparse.ArgumentParser(description='start the computing node')
     parser.add_argument('--port', type=str, help="Port of the Computing node", required=True)
     parser.add_argument('--valgrind', help="whether to use valgrind", default=False, action='store_true')
+    parser.add_argument('--nopreload', help="whether to avoid setting LD_PRELOAD ", default=False, action='store_true')
     args = parser.parse_args()
     port = args.port
 
@@ -40,6 +41,8 @@ if __name__ == "__main__":
 
     cmd0 = "export LD_LIBRARY_PATH=" + install_path + "/lib:$LD_LIBRARY_PATH;"
     cmd1 = 'export LD_PRELOAD="' + install_path + '/resources/libjemalloc.so"; ulimit -c unlimited; '
+    if args.nopreload:
+        cmd1 = ""
     prefix = ""
     if args.valgrind:
         prefix = "valgrind --leak-check=full --trace-children=yes --undef-value-errors=no "
